C**********************************************************************
C                          ADAPT II                                   *
C                         Release  4                                  *
C**********************************************************************
C                                                                     *
C                           MODEL                                     *
C                                                                     *
C    This file contains the Fortran subroutines listed below in       *
C    which the user must enter the relevant equations and constants.  *
C    Consult the user's manual for details concerning the format for  *
C    entered equations and definition of symbols.                     *
C                                                                     *
C       1. DiffEq- System differential equations.                     *
C       2. Amat  - System state matrix.                               *
C       3. Output- System output equations.                           *
C       4. Symbol- Parameter symbols and model constants.             *
C       5. Varmod- Error variance model equations.                    *
C       6. Prior - Parameter mean and covariance values               *
C       7. Sparam- Secondary parameters                               *
C                                                                     *
C**********************************************************************

C Onco-Model Control Data
C
C 24.02.09, Gilbert Koch (University of Konstanz)
C           gilbert.koch@uni-konstanz.de
C           http://www.math.uni-konstanz.de/numerik/personen/koch/
C 
C - Fit control data 


        Subroutine DIFFEQ(T,X,XP)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 T,X(MaxNDE),XP(MaxNDE)

	Real*8 l0, l1, w0

	l0 = P(1)
	l1 = P(2)
	w0 = P(3)

	XP(1) = (2*l0*l1*(X(1)+w0))/(l1 + 2*l0*(X(1)+w0))

        Return
        End


C######################################################################C

        Subroutine AMAT(A)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 A(MaxNDE,MaxNDE)

        DO I=1,Ndeqs
           Do J=1,Ndeqs
              A(I,J)=0.0D0
           End Do
        End Do

CC
C----------------------------------------------------------------------C
C 2. Enter non zero elements of state matrix  {e.g.  A(1,1) = -P(1) }  C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine OUTPUT(Y,T,X)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 Y(MaxNOE),T,X(MaxNDE)

CC
C----------------------------------------------------------------------C
C 3.  Enter Output Equations Below   {e.g.  Y(1) = X(1)/P(2) }         C
C----c-----------------------------------------------------------------C

        Y(1) = X(1) + P(3)

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine SYMBOL
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

CC
C----------------------------------------------------------------------C
C 4.                Enter as Indicated                                 C
C----c-----------------------------------------------------------------C

      NDEqs   =  1  ! Enter # of Diff. Eqs.
      NSParam =  3  ! Enter # of System Parameters.
      NVparam =  2  ! Enter # of Variance Parameters.
      NSecPar =  0  ! Enter # of Secondary Parameters.
      NSecOut =  0  ! Enter # of Secondary Outputs (not used).
      Ieqsol  =  1  ! Model type: 1 - DIFFEQ, 2 - AMAT, 3 - OUTPUT only.
      Descr   = 'Control_Data_Model'

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
CC
C----------------------------------------------------------------------C
C 4.  Enter Symbol for Each System Parameter (eg. Psym(1)='Kel')       C
C----c-----------------------------------------------------------------C

       	Psym(1) = 'l0'
	Psym(2) = 'l1'
	Psym(3) = 'w0'

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
CC
C----------------------------------------------------------------------C
C 4. Enter Symbol for Each Variance Parameter {eg: PVsym(1)='Sigma'}   C
C----c-----------------------------------------------------------------C

        PVsym(1) = 'sigma1'
	PVsym(2) = 'sigma2'

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
CC
C----------------------------------------------------------------------C
C 4. Enter Symbol for Each Secondary Parameter {eg: PSsym(1)='CLt'}    C
C----c-----------------------------------------------------------------C


C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine VARMOD(V,T,X,Y)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 V(MaxNOE),T,X(MaxNDE),Y(MaxNOE)

CC
C----------------------------------------------------------------------C
C 5.    Enter Variance Model Equations Below                           C
C         {e.g. V(1) = (PV(1) + PV(2)*Y(1))**2 }                        C
C----c-----------------------------------------------------------------C

        V(1) = (PV(1) + PV(2)*Y(1))**2

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine PRIOR(Pmean,Pcov,ICmean,ICcov)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 Pmean(MaxNSP+MaxNDE), ICmean(MaxNDE)
        Real*8 Pcov(MaxNSP+MaxNDE,MaxNSP+MaxNDE), ICcov(MaxNDE,MaxNDE)

CC
C----------------------------------------------------------------------C
C 6.    Enter Nonzero Elements of Prior Mean Vector                    C
C          {  e.g. Pmean(2) = 10.0    }                                C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
CC
C----------------------------------------------------------------------C
C 6. Enter Nonzero Elements of Covariance Matrix (Lower Triang.)       C
C         {  e.g. Pcov(2,1) = 0.25    }                                C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine SPARAM(PS,P,IC)
        Implicit None

        Include 'globals.inc'

        Real*8 PS(MaxNSECP), P(MaxNSP+MaxNDE), IC(MaxNDE) 

CC
C----------------------------------------------------------------------C
C 7.    Enter Equations Defining Secondary Paramters                   C
C           {  e.g.  PS(1) = P(1)*P(2)   }                             C
C----c-----------------------------------------------------------------C

     
C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End
