C**********************************************************************
C                          ADAPT II                                   *
C                         Release  4                                  *
C**********************************************************************
C                                                                     *
C                           MODEL                                     *
C                                                                     *
C    This file contains the Fortran subroutines listed below in       *
C    which the user must enter the relevant equations and constants.  *
C    Consult the user's manual for details concerning the format for  *
C    entered equations and definition of symbols.                     *
C                                                                     *
C       1. DiffEq- System differential equations.                     *
C       2. Amat  - System state matrix.                               *
C       3. Output- System output equations.                           *
C       4. Symbol- Parameter symbols and model constants.             *
C       5. Varmod- Error variance model equations.                    *
C       6. Prior - Parameter mean and covariance values               *
C       7. Sparam- Secondary parameters                               *
C                                                                     *
C**********************************************************************


C Onco-Model Monotherapy
C
C 24.02.09, Gilbert Koch (University of Konstanz)
C           gilbert.koch@uni-konstanz.de
C           http://www.math.uni-konstanz.de/numerik/personen/koch/
C
C - Simultaneous fit of control data and Drug C 150 (2-Comp.)
C
C - PK is modeled with differential equations and controlled by 
C   a bolus function b1(t)


	Subroutine DIFFEQ(T,X,XP)
    	Implicit None

    	Include 'globals.inc'
    	Include 'model.inc'

	Real*8 T,X(MaxNDE),XP(MaxNDE)

    	Real*8 ka_d1, k21_d1, k12_d1, k10_d1, V_d1
    	Real*8 l0, l1, k1, k2, w0
    	Real*8 conc, wt_unp, wt_per, gr_unp, gr_per


C  PK Drug C 150 (Unit 1/day)
    	ka_d1   = 1431.30620233
    	k21_d1  = 50.80220076
    	k10_d1  =  9.61528508
   	k12_d1  = 63.05556308
    	V_d1    = 2.40938460


C  PD Parameters 
    	l0  = P(1)
    	l1  = P(2)
    	k1  = P(3)
    	k2  = P(4)
    	w0  = P(5)


C  2 Comp. p.o.
    	XP(1) = ka_d1*X(3) - k12_d1*X(1) - k10_d1*X(1) + k21_d1*X(2)
    	XP(2) = -k21_d1*X(2) + k12_d1*X(1)
    	XP(3) = -ka_d1*X(3)

    	conc = X(1) / V_d1


C  Onco-Model
    	wt_unp = X(4) + w0
    	wt_per = X(5) + X(6) + X(7) + X(8) + w0

    	gr_unp = (2*l0*l1*(X(4)+w0)**2)/((l1 + 2*l0*(X(4)+w0))*wt_unp)
    	gr_per = (2*l0*l1*(X(5)+w0)**2)/((l1 + 2*l0*(X(5)+w0))*wt_per)

  	XP(4) = gr_unp
	XP(5) = gr_per - (k2*conc)*(X(5)+w0)
	XP(6) = (k2*conc)*(X(5)+w0) - k1*X(6)
	XP(7) = k1*(X(6)-X(7))
	XP(8) = k1*(X(7)-X(8))	


	Return
	End


C######################################################################C

        Subroutine AMAT(A)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 A(MaxNDE,MaxNDE)

        DO I=1,Ndeqs
           Do J=1,Ndeqs
              A(I,J)=0.0D0
           End Do
        End Do

CC
C----------------------------------------------------------------------C
C 2. Enter non zero elements of state matrix  {e.g.  A(1,1) = -P(1) }  C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine OUTPUT(Y,T,X)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 Y(MaxNOE),T,X(MaxNDE)

CC
C----------------------------------------------------------------------C
C 3.  Enter Output Equations Below   {e.g.  Y(1) = X(1)/P(2) }         C
C----c-----------------------------------------------------------------C

        Y(1) = X(4) + P(5)
        Y(2) = X(5) + X(6) + X(7) + X(8) + P(5)

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine SYMBOL
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

CC
C----------------------------------------------------------------------C
C 4.                Enter as Indicated                                 C
C----c-----------------------------------------------------------------C

      NDEqs   =  8  ! Enter # of Diff. Eqs.
      NSParam =  5  ! Enter # of System Parameters.
      NVparam =  2  ! Enter # of Variance Parameters.
      NSecPar =  0  ! Enter # of Secondary Parameters.
      NSecOut =  0  ! Enter # of Secondary Outputs (not used).
      Ieqsol  =  1  ! Model type: 1 - DIFFEQ, 2 - AMAT, 3 - OUTPUT only.
      Descr   = 'Mono_C_150'

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
CC
C----------------------------------------------------------------------C
C 4.  Enter Symbol for Each System Parameter (eg. Psym(1)='Kel')       C
C----c-----------------------------------------------------------------C

       	Psym(1) = 'l0'
	Psym(2) = 'l1'
	Psym(3) = 'k1'
	Psym(4) = 'k2'
	Psym(5) = 'w0'

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
CC
C----------------------------------------------------------------------C
C 4. Enter Symbol for Each Variance Parameter {eg: PVsym(1)='Sigma'}   C
C----c-----------------------------------------------------------------C

        PVsym(1) = 'sigma1'
        PVsym(2) = 'sigma2'

C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
CC
C----------------------------------------------------------------------C
C 4. Enter Symbol for Each Secondary Parameter {eg: PSsym(1)='CLt'}    C
C----c-----------------------------------------------------------------C


C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine VARMOD(V,T,X,Y)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Real*8 V(MaxNOE),T,X(MaxNDE),Y(MaxNOE)

CC
C----------------------------------------------------------------------C
C 5.    Enter Variance Model Equations Below                           C
C         {e.g. V(1) = (PV(1) + PV(2)*Y(1))**2 }                        C
C----c-----------------------------------------------------------------C

        V(1) = (PV(1) + PV(2)*Y(1))**2
        V(2) = (PV(1) + PV(2)*Y(2))**2


C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine PRIOR(Pmean,Pcov,ICmean,ICcov)
        Implicit None

        Include 'globals.inc'
        Include 'model.inc'

        Integer I,J
        Real*8 Pmean(MaxNSP+MaxNDE), ICmean(MaxNDE)
        Real*8 Pcov(MaxNSP+MaxNDE,MaxNSP+MaxNDE), ICcov(MaxNDE,MaxNDE)

CC
C----------------------------------------------------------------------C
C 6.    Enter Nonzero Elements of Prior Mean Vector                    C
C          {  e.g. Pmean(2) = 10.0    }                                C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
CC
C----------------------------------------------------------------------C
C 6. Enter Nonzero Elements of Covariance Matrix (Lower Triang.)       C
C         {  e.g. Pcov(2,1) = 0.25    }                                C
C----c-----------------------------------------------------------------C



C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End


C######################################################################C

        Subroutine SPARAM(PS,P,IC)
        Implicit None

        Include 'globals.inc'

        Real*8 PS(MaxNSECP), P(MaxNSP+MaxNDE), IC(MaxNDE) 

CC
C----------------------------------------------------------------------C
C 7.    Enter Equations Defining Secondary Paramters                   C
C           {  e.g.  PS(1) = P(1)*P(2)   }                             C
C----c-----------------------------------------------------------------C

     
C----------------------------------------------------------------------C
C----------------------------------------------------------------------C
C
        Return
        End
